@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::YANICK;
 our $AUTHORITY = 'cpan:YANICK';
-$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.29.1';
+$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.30.0';
 # ABSTRACT: Be like Yanick when you build your dists
 
 # [TODO] add CONTRIBUTING file
@@ -210,9 +210,10 @@ sub configure {
             process_changes => $self->doap_changelog,
 #            ttl_filename => 'project.ttl',
         } ],
-        [ 'CPANFile' ],
+        [ 'CPANFile', 'MinimumPerlFast' ],
     );
 
+
     $self->config_slice( 'mb_class' );
 
     return;
@@ -232,7 +233,7 @@ Dist::Zilla::PluginBundle::YANICK - Be like Yanick when you build your dists
 
 =head1 VERSION
 
-version 0.29.1
+version 0.30.0
 
 =head1 DESCRIPTION
 
@@ -344,6 +345,8 @@ his distributions. It's roughly equivalent to
 
     [GitHubREADME::Badge]
 
+    [MinimumPerlFast]
+
 =head2 ARGUMENTS
 
 =head3 autoprereqs_skip
